@@ -45,16 +45,13 @@ telemetry_group = cfg.OptGroup(name='telemetry',
 telemetry_services_group = cfg.OptGroup(name='telemetry_services',
                                         title='Telemetry Services')
 
-event_group = cfg.OptGroup(name='event',
-                           title='Event Service Options')
-
 alarming_group = cfg.OptGroup(name='alarming_plugin',
                               title='Alarming Service Options')
 
 metric_group = cfg.OptGroup(name='metric',
                             title='Metric Service Options')
 
-TelemetryGroup = [
+telemetry_opts = [
     cfg.IntOpt('notification_wait',
                default=120,
                help="The seconds to wait for notifications which "
@@ -96,7 +93,20 @@ TelemetryGroup = [
     cfg.IntOpt('prometheus_scrape_interval',
                default=15,
                help="Scrape interval configured for prometheus. This can "
-                    "be used in test cases to properly configure autoscaling")
+                    "be used in test cases to properly configure autoscaling"),
+    cfg.StrOpt(
+        'autoscaling_instance_grouping',
+        default='metadata',
+        choices=[
+            ('prefix', 'Use a common string at the start of instance names to '
+                       'group instances'),
+            ('metadata', 'Use metering.server_group instance metadata to '
+                         'group instances. This is preferred method since '
+                         '2025.1')
+        ],
+        help="The method to group instances for autoscaling testing. Note "
+             "that this option affects only tests with prometheus metric "
+             "backend")
 ]
 
 telemetry_services_opts = [
@@ -110,18 +120,7 @@ telemetry_services_opts = [
                help="Database used by the aodh service"),
 ]
 
-event_opts = [
-    cfg.StrOpt('catalog_type',
-               default='event',
-               help="Catalog type of the Event service."),
-    cfg.StrOpt('endpoint_type',
-               default='publicURL',
-               choices=['public', 'admin', 'internal',
-                        'publicURL', 'adminURL', 'internalURL'],
-               help="The endpoint type to use for the event service."),
-]
-
-AlarmingGroup = [
+alarming_opts = [
     cfg.StrOpt('catalog_type',
                default='alarming',
                help="Catalog type of the Alarming service."),
